==> nextcloud-15.0.2-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/files/l10n/pt_PT.js <==
OC.L10N.register(
    "files",
    {
    "Storage is temporarily not available" : "Armazenamento temporariamente indisponível",
    "Storage invalid" : "Armazenamento inválido",
    "Unknown error" : "Erro desconhecido",
    "All files" : "Todos os ficheiros",
    "Recent" : "Recentes",
    "Favorites" : "Favoritos",
    "File could not be found" : "O ficheiro não foi encontrado",
    "Move or copy" : "Mover ou copiar",
    "Download" : "Transferir",
    "Delete" : "Eliminar",
    "Home" : "Início",
    "Close" : "Fechar",
    "Could not create folder \"{dir}\"" : "Não foi possível criar a pasta \"{dir}\"",
    "Upload cancelled." : "Envio cancelado.",
    "…" : "...",
    "Unable to upload {filename} as it is a directory or has 0 bytes" : "Não é possível enviar {filename}, porque este é uma diretoria ou tem 0 bytes",
    "Not enough free space, you are uploading {size1} but only {size2} is left" : "Não existe espaço suficiente, está a enviar {size1} mas resta apenas {size2}",
    "Target folder \"{dir}\" does not exist any more" : "A pasta de destino \"{dir}\" já não existe",
    "Not enough free space" : "Espaço insuficiente",
    "Uploading …" : "A carregar ...",
    "{loadedSize} of {totalSize} ({bitrate})" : "{loadedSize} de {totalSize} ({bitrate})",
    "Target folder does not exist any more" : "A pasta de destino já não existe",
    "Error when assembling chunks, status code {status}" : "Erro ao agregar partições, código de estado: {estado}",
    "Actions" : "Ações",
    "Rename" : "Renomear",
    "Disconnect storage" : "Desligue o armazenamento",
    "Unshare" : "Cancelar partilha",
    "Could not load info for file \"{file}\"" : "Não foi possível carregar informações do ficheiro \"{file}\"",
    "Files" : "Ficheiros",
    "Details" : "Detalhes",
    "Select" : "Selecionar",
    "Pending" : "Pendente",
    "Unable to determine date" : "Não é possível determinar a data",
    "This operation is forbidden" : "Esta operação é proibida",
    "This directory is unavailable, please check the logs or contact the administrator" : "Esta diretoria está indisponível, por favor, verifique os registos ou contacte o administrador",
    "Could not move \"{file}\", target exists" : "Não foi possível mover \"{file}\", destino já existe",
    "Could not move \"{file}\"" : "Não foi possivel mover o ficheiro \"{file}\"",
    "Could not copy \"{file}\", target exists" : "Não foi possível copiar \"{file}\", o destino já existe",
    "Could not copy \"{file}\"" : "Impossível copiar \"{file}\"",
    "Copied {origin} inside {destination}" : "Copiado {origin} para {destination}",
    "Copied {origin} and {nbfiles} other files inside {destination}" : "Copiados {origin} e {nbfiles} outros ficheiros para dentro de {destination}",
    "{newName} already exists" : "{newName} já existe",
    "Could not rename \"{fileName}\", it does not exist any more" : "Não foi possível renomear \"{fileName}\", este já não existe",
    "The name \"{targetName}\" is already used in the folder \"{dir}\". Please choose a different name." : "O nome \"{targetName}\" já está em utilização na pasta \"{dir}\". Por favor, escolha um nome diferente.",
    "Could not rename \"{fileName}\"" : "Não foi possível renomear \"{fileName}\"",
    "Could not create file \"{file}\"" : "Não foi possível criar o ficheiro \"{file}\"",
    "Could not create file \"{file}\" because it already exists" : "Não foi possível criar o ficheiro \"{file}\", porque este já existe",
    "Could not create folder \"{dir}\" because it already exists" : "Não foi possível criar a pasta \"{dir}\", porque esta já existe",
    "Error deleting file \"{fileName}\"." : "Erro ao eliminar o ficheiro \"{fileName}\".",
    "No search results in other folders for {tag}{filter}{endtag}" : "Nenhum resultado noutras pastas para {tag}{filter}{endtag}",
    "Name" : "Nome",
    "Size" : "Tamanho",
    "Modified" : "Modificado",
    "_%n folder_::_%n folders_" : ["%n pasta","%n pastas"],
    "_%n file_::_%n files_" : ["%n ficheiro","%n ficheiros"],
    "{dirs} and {files}" : "{dirs} e {files}",
    "_including %n hidden_::_including %n hidden_" : ["incluindo %n ocultos","incluindo %n ocultos"],
    "You don’t have permission to upload or create files here" : "Não tem permissão para enviar ou criar ficheiros aqui",
    "_Uploading %n file_::_Uploading %n files_" : ["A enviar %n ficheiro","A enviar %n ficheiros"],
    "New" : "Novo",
    "{used} of {quota} used" : "{used} de {quota} utilizado",
    "{used} used" : "{used} utilizado",
    "\"{name}\" is an invalid file name." : "\"{name}\" é um nome de ficheiro inválido.",
    "File name cannot be empty." : "O nome do ficheiro não pode estar em branco.",
    "\"/\" is not allowed inside a file name." : "\"/\" não é permitido dentro de um nome de um ficheiro.",
    "\"{name}\" is not an allowed filetype" : "\"{name}\" não é um tipo de ficheiro permitido",
    "Storage of {owner} is full, files can not be updated or synced anymore!" : "O armazenamento de {owner} está cheio. Os ficheiros já não podem ser atualizados ou sincronizados!",
    "Your storage is full, files can not be updated or synced anymore!" : "O seu armazenamento está cheio, os ficheiros já não podem ser atualizados ou sincronizados.",
    "Storage of {owner} is almost full ({usedSpacePercent}%)" : "O armazenamento de {owner} está quase cheio ({usedSpacePercent}%)",
    "Your storage is almost full ({usedSpacePercent}%)" : "O seu armazenamento está quase cheio ({usedSpacePercent}%)",
    "_matches '{filter}'_::_match '{filter}'_" : ["corresponde a '{filter}'","correspondem a '{filter}'"],
    "View in folder" : "Ver na pasta",
    "Copied!" : "Copiado!",
    "Copy direct link (only works for users who have access to this file/folder)" : "Copiar hiperligação directa (apenas funciona para utilizadores que tenham acesso a este ficheiro/pasta)",
    "Path" : "Caminho",
    "_%n byte_::_%n bytes_" : ["%n byte","%n bytes"],
    "Favorited" : "Nos Favoritos",
    "Favorite" : "Favorito",
    "New folder" : "Nova pasta",
    "Upload file" : "Enviar ficheiro",
    "Not favorited" : "Não favorito",
    "Remove from favorites" : "Remover dos favoritos",
    "Add to favorites" : "Adicionar aos favoritos",
    "An error occurred while trying to update the tags" : "Ocorreu um erro ao tentar atualizar as etiquetas",
    "Added to favorites" : "Adicionado aos favoritos",
    "Removed from favorites" : "Removido dos favoritos",
    "You added {file} to your favorites" : "Adicionou {file} aos favoritos",
    "You removed {file} from your favorites" : "Removeu {file} dos favoritos",
    "File changes" : "Alterações no ficheiro",
    "Created by {user}" : "Criado por {user}",
    "Changed by {user}" : "Modificado por {user}",
    "Deleted by {user}" : "Apagado por {user}",
    "Restored by {user}" : "Restaurado por {user}",
    "Renamed by {user}" : "Renomeado por {user}",
    "Moved by {user}" : "Movido por {user}",
    "\"remote user\"" : "\"utilizador remoto\"",
    "You created {file}" : "Criou {file}",
    "{user} created {file}" : "{user} criou {file}",
    "{file} was created in a public folder" : "{file} foi criado numa pasta pública",
    "You changed {file}" : "Modificou {file}",
    "{user} changed {file}" : "{user} modificou {file}",
    "You deleted {file}" : "Eliminou {file}",
    "{user} deleted {file}" : "{user} eliminou {file}",
    "You restored {file}" : "Restaurou {file}",
    "{user} restored {file}" : "{user} restaurou {file}",
    "You renamed {oldfile} to {newfile}" : "Renomeou {oldfile} para {newfile}",
    "{user} renamed {oldfile} to {newfile}" : "{user} renomeou {oldfile} para {newfile}",
    "You moved {oldfile} to {newfile}" : "Moveu {oldfile} para {newfile}",
    "{user} moved {oldfile} to {newfile}" : "{user} moveu {oldfile} para {newfile}",
    "A file has been added to or removed from your <strong>favorites</strong>" : "Um ficheiro foi adicionado ou removido dos seus <strong>favoritos</strong>",
    "A file or folder has been <strong>changed</strong> or <strong>renamed</strong>" : "Um ficheiro ou pasta foram <strong>modificados</strong> ou <strong>renomeados</strong>",
    "A new file or folder has been <strong>created</strong>" : "Foi <strong>criado</strong> um novo ficheiro ou pasta",
    "A file or folder has been <strong>deleted</strong>" : "Um ficheiro ou pasta foram <strong>apagados</strong>",
    "Limit notifications about creation and changes to your <strong>favorite files</strong> <em>(Stream only)</em>" : "Limite as notificações sobre a criação e alterações para os seus <strong>ficheiros favoritos</strong> <em>(apenas Emissão)</em>",
    "A file or folder has been <strong>restored</strong>" : "Um ficheiro ou pasta foram <strong>restaurados</strong>",
    "Unlimited" : "Ilimitado",
    "Upload (max. %s)" : "Envio (máx. %s)",
    "File handling" : "Utilização do ficheiro",
    "Maximum upload size" : "Tamanho máximo de envio",
    "max. possible: " : "Máx. possível: ",
    "Save" : "Guardar",
    "With PHP-FPM it might take 5 minutes for changes to be applied." : "Com o PHP-FPM poderá demorar 5 minutos até que as alterações sejam aplicadas.",
    "Missing permissions to edit from here." : "Faltam permissões para editar a partir daqui.",
    "%s of %s used" : "%s de %s utilizado",
    "%s used" : "%s utilizado",
    "Settings" : "Configurações",
    "Show hidden files" : "Mostrar ficheiros ocultos",
    "WebDAV" : "WebDAV",
    "Use this address to <a href=\"%s\" target=\"_blank\" rel=\"noreferrer noopener\">access your Files via WebDAV</a>" : "Utilize este endereço para <a href=\"%s\" target=\"_blank\" rel=\"noreferrer noopener\">aceder aos seus ficheiros por WebDAV</a>",
    "Cancel upload" : "Cancelar envio",
    "No files in here" : "Nenhuns ficheiros aqui",
    "Upload some content or sync with your devices!" : "Envie algum conteúdo ou sincronize com os seus dispositivos!",
    "No entries found in this folder" : "Não foram encontradas entradas nesta pasta",
    "Select all" : "Selecionar todos",
    "Upload too large" : "Envio muito grande",
    "The files you are trying to upload exceed the maximum size for file uploads on this server." : "Os ficheiros que está a tentar enviar excedem o tamanho máximo para os envios de ficheiro neste servidor.",
    "No favorites yet" : "Sem favoritos",
    "Files and folders you mark as favorite will show up here" : "Os ficheiros e pastas que marcou como favoritos serão mostrados aqui",
    "Tags" : "Etiquetas",
    "Deleted files" : "Ficheiros eliminados",
    "Shared with others" : "Partilhado com terceiros",
    "Shared with you" : "Partilhado consigo ",
    "Shared by link" : "Partilhado por hiperligação",
    "Text file" : "Ficheiro de Texto",
    "New text file.txt" : "Novo texto ficheiro.txt",
    "Target folder" : "Pasta de destino"
},
"nplurals=2; plural=(n != 1);");

==> nextcloud-16.0.0-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/files/l10n/pt_PT.js <==
OC.L10N.register(
    "files",
    {
    "Storage is temporarily not available" : "Armazenamento temporariamente indisponível",
    "Storage invalid" : "Armazenamento inválido",
    "Unknown error" : "Erro desconhecido",
    "All files" : "Todos os ficheiros",
    "Recent" : "Recentes",
    "Favorites" : "Favoritos",
    "File could not be found" : "O ficheiro não foi encontrado",
    "Move or copy" : "Mover ou copiar",
    "Download" : "Transferir",
    "Delete" : "Eliminar",
    "Home" : "Início",
    "Close" : "Fechar",
    "Could not create folder \"{dir}\"" : "Não foi possível criar a pasta \"{dir}\"",
    "Upload cancelled." : "Envio cancelado.",
    "…" : "...",
    "Unable to upload {filename} as it is a directory or has 0 bytes" : "Não é possível enviar {filename}, porque este é uma diretoria ou tem 0 bytes",
    "Not enough free space, you are uploading {size1} but only {size2} is left" : "Não existe espaço suficiente, está a enviar {size1} mas resta apenas {size2}",
    "Target folder \"{dir}\" does not exist any more" : "A pasta de destino \"{dir}\" já não existe",
    "Not enough free space" : "Espaço insuficiente",
    "Uploading …" : "A carregar ...",
    "{loadedSize} of {totalSize} ({bitrate})" : "{loadedSize} de {totalSize} ({bitrate})",
    "Target folder does not exist any more" : "A pasta de destino já não existe",
    "Error when assembling chunks, status code {status}" : "Erro ao agregar partições, código de estado: {estado}",
    "Actions" : "Ações",
    "Rename" : "Renomear",
    "Disconnect storage" : "Desligue o armazenamento",
    "Unshare" : "Cancelar partilha",
    "Could not load info for file \"{file}\"" : "Não foi possível carregar informações do ficheiro \"{file}\"",
    "Files" : "Ficheiros",
    "Details" : "Detalhes",
    "Select" : "Selecionar",
    "Pending" : "Pendente",
    "Unable to determine date" : "Não é possível determinar a data",
    "This operation is forbidden" : "Esta operação é proibida",
    "This directory is unavailable, please check the logs or contact the administrator" : "Esta diretoria está indisponível, por favor, verifique os registos ou contacte o administrador",
    "Could not move \"{file}\", target exists" : "Não foi possível mover \"{file}\", destino já existe",
    "Could not move \"{file}\"" : "Não foi possivel mover o ficheiro \"{file}\"",
    "Could not copy \"{file}\", target exists" : "Não foi possível copiar \"{file}\", o destino já existe",
    "Could not copy \"{file}\"" : "Impossível copiar \"{file}\"",
    "Copied {origin} inside {destination}" : "Copiado {origin} para {destination}",
    "Copied {origin} and {nbfiles} other files inside {destination}" : "Copiados {origin} e {nbfiles} outros ficheiros para dentro de {destination}",
    "{newName} already exists" : "{newName} já existe",
    "Could not rename \"{fileName}\", it does not exist any more" : "Não foi possível renomear \"{fileName}\", este já não existe",
    "The name \"{targetName}\" is already used in the folder \"{dir}\". Please choose a different name." : "O nome \"{targetName}\" já está em utilização na pasta \"{dir}\". Por favor, escolha um nome diferente.",
    "Could not rename \"{fileName}\"" : "Não foi possível renomear \"{fileName}\"",
    "Could not create file \"{file}\"" : "Não foi possível criar o ficheiro \"{file}\"",
    "Could not create file \"{file}\" because it already exists" : "Não foi possível criar o ficheiro \"{file}\", porque este já existe",
    "Could not create folder \"{dir}\" because it already exists" : "Não foi possível criar a pasta \"{dir}\", porque esta já existe",
    "Error deleting file \"{fileName}\"." : "Erro ao eliminar o ficheiro \"{fileName}\".",
    "No search results in other folders for {tag}{filter}{endtag}" : "Nenhum resultado noutras pastas para {tag}{filter}{endtag}",
    "Name" : "Nome",
    "Size" : "Tamanho",
    "Modified" : "Modificado",
    "_%n folder_::_%n folders_" : ["%n pasta","%n pastas"],
    "_%n file_::_%n files_" : ["%n ficheiro","%n ficheiros"],
    "{dirs} and {files}" : "{dirs} e {files}",
    "_including %n hidden_::_including %n hidden_" : ["incluindo %n ocultos","incluindo %n ocultos"],
    "You don’t have permission to upload or create files here" : "Não tem permissão para enviar ou criar ficheiros aqui",
    "_Uploading %n file_::_Uploading %n files_" : ["A enviar %n ficheiro","A enviar %n ficheiros"],
    "New" : "Novo",
    "{used} of {quota} used" : "{used} de {quota} utilizado",
    "{used} used" : "{used} utilizado",
    "\"{name}\" is an invalid file name." : "\"{name}\" é um nome de ficheiro inválido.",
    "File name cannot be empty." : "O nome do ficheiro não pode estar em branco.",
    "\"/\" is not allowed inside a file name." : "\"/\" não é permitido dentro de um nome de um ficheiro.",
    "\"{name}\" is not an allowed filetype" : "\"{name}\" não é um tipo de ficheiro permitido",
    "Storage of {owner} is full, files can not be updated or synced anymore!" : "O armazenamento de {owner} está cheio. Os ficheiros já não podem ser atualizados ou sincronizados!",
    "Your storage is full, files can not be updated or synced anymore!" : "O seu armazenamento está cheio, os ficheiros já não podem ser atualizados ou sincronizados.",
    "Storage of {owner} is almost full ({usedSpacePercent}%)" : "O armazenamento de {owner} está quase cheio ({usedSpacePercent}%)",
    "Your storage is almost full ({usedSpacePercent}%)" : "O seu armazenamento está quase cheio ({usedSpacePercent}%)",
    "_matches '{filter}'_::_match '{filter}'_" : ["corresponde a '{filter}'","correspondem a '{filter}'"],
    "View in folder" : "Ver na pasta",
    "Copied!" : "Copiado!",
    "Copy direct link (only works for users who have access to this file/folder)" : "Copiar hiperligação directa (apenas funciona para utilizadores que tenham acesso a este ficheiro/pasta)",
    "Path" : "Caminho",
    "_%n byte_::_%n bytes_" : ["%n byte","%n bytes"],
    "Favorited" : "Nos Favoritos",
    "Favorite" : "Favorito",
    "New folder" : "Nova pasta",
    "Upload file" : "Enviar ficheiro",
    "Not favorited" : "Não favorito",
    "Remove from favorites" : "Remover dos favoritos",
    "Add to favorites" : "Adicionar aos favoritos",
    "An error occurred while trying to update the tags" : "Ocorreu um erro ao tentar atualizar as etiquetas",
    "Added to favorites" : "Adicionado aos favoritos",
    "Removed from favorites" : "Removido dos favoritos",
    "You added {file} to your favorites" : "Adicionou {file} aos favoritos",
    "You removed {file} from your favorites" : "Removeu {file} dos favoritos",
    "File changes" : "Alterações no ficheiro",
    "Created by {user}" : "Criado por {user}",
    "Changed by {user}" : "Modificado por {user}",
    "Deleted by {user}" : "Apagado por {user}",
    "Restored by {user}" : "Restaurado por {user}",
    "Renamed by {user}" : "Renomeado por {user}",
    "Moved by {user}" : "Movido por {user}",
    "\"remote user\"" : "\"utilizador remoto\"",
    "You created {file}" : "Criou {file}",
    "{user} created {file}" : "{user} criou {file}",
    "{file} was created in a public folder" : "{file} foi criado numa pasta pública",
    "You changed {file}" : "Modificou {file}",
    "{user} changed {file}" : "{user} modificou {file}",
    "You deleted {file}" : "Eliminou {file}",
    "{user} deleted {file}" : "{user} eliminou {file}",
    "You restored {file}" : "Restaurou {file}",
    "{user} restored {file}" : "{user} restaurou {file}",
    "You renamed {oldfile} to {newfile}" : "Renomeou {oldfile} para {newfile}",
    "{user} renamed {oldfile} to {newfile}" : "{user} renomeou {oldfile} para {newfile}",
    "You moved {oldfile} to {newfile}" : "Moveu {oldfile} para {newfile}",
    "{user} moved {oldfile} to {newfile}" : "{user} moveu {oldfile} para {newfile}",
    "A file has been added to or removed from your <strong>favorites</strong>" : "Um ficheiro foi adicionado ou removido dos seus <strong>favoritos</strong>",
    "A file or folder has been <strong>changed</strong> or <strong>renamed</strong>" : "Um ficheiro ou pasta foram <strong>modificados</strong> ou <strong>renomeados</strong>",
    "A new file or folder has been <strong>created</strong>" : "Foi <strong>criado</strong> um novo ficheiro ou pasta",
    "A file or folder has been <strong>deleted</strong>" : "Um ficheiro ou pasta foram <strong>apagados</strong>",
    "Limit notifications about creation and changes to your <strong>favorite files</strong> <em>(Stream only)</em>" : "Limite as notificações sobre a criação e alterações para os seus <strong>ficheiros favoritos</strong> <em>(apenas Emissão)</em>",
    "A file or folder has been <strong>restored</strong>" : "Um ficheiro ou pasta foram <strong>restaurados</strong>",
    "Unlimited" : "Ilimitado",
    "Upload (max. %s)" : "Envio (máx. %s)",
    "%s of %s used" : "%s de %s utilizado",
    "%s used" : "%s utilizado",
    "Settings" : "Configurações",
    "Show hidden files" : "Mostrar ficheiros ocultos",
    "WebDAV" : "WebDAV",
    "Use this address to <a href=\"%s\" target=\"_blank\" rel=\"noreferrer noopener\">access your Files via WebDAV</a>" : "Utilize este endereço para <a href=\"%s\" target=\"_blank\" rel=\"noreferrer noopener\">aceder aos seus ficheiros por WebDAV</a>",
    "No files in here" : "Nenhuns ficheiros aqui",
    "Upload some content or sync with your devices!" : "Envie algum conteúdo ou sincronize com os seus dispositivos!",
    "No entries found in this folder" : "Não foram encontradas entradas nesta pasta",
    "Select all" : "Selecionar todos",
    "Upload too large" : "Envio muito grande",
    "The files you are trying to upload exceed the maximum size for file uploads on this server." : "Os ficheiros que está a tentar enviar excedem o tamanho máximo para os envios de ficheiro neste servidor.",
    "No favorites yet" : "Sem favoritos",
    "Files and folders you mark as favorite will show up here" : "Os ficheiros e pastas que marcou como favoritos serão mostrados aqui",
    "Tags" : "Etiquetas",
    "Deleted files" : "Ficheiros eliminados",
    "Shared with others" : "Partilhado com terceiros",
    "Shared with you" : "Partilhado consigo ",
    "Shared by link" : "Partilhado por hiperligação",
    "Text file" : "Ficheiro de Texto",
    "New text file.txt" : "Novo texto ficheiro.txt",
    "Target folder" : "Pasta de destino",
    "File handling" : "Utilização do ficheiro",
    "Maximum upload size" : "Tamanho máximo de envio",
    "max. possible: " : "Máx. possível: ",
    "Save" : "Guardar",
    "With PHP-FPM it might take 5 minutes for changes to be applied." : "Com o PHP-FPM poderá demorar 5 minutos até que as alterações sejam aplicadas.",
    "Missing permissions to edit from here." : "Faltam permissões para editar a partir daqui.",
    "Cancel upload" : "Cancelar envio"
},
"nplurals=2; plural=(n != 1);");
